#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright 2012 Liricus SRL <info@liricus.com.ar>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Fra


#===============================================================================
# DOCS
#===============================================================================

"""Utilities to manipulate files.

"""


#===============================================================================
# IMPORTS
#===============================================================================

import hashlib
import os

try:
    import ImageFile
    import Image
except ImportError:
    from PIL import Image
    from PIL import ImageFile

from socialframe_server import core


#===============================================================================
# FUNCTIONS
#===============================================================================

def sha(path):
    """Returns the content of a file hashed.
    
    **Parameters**
        
        :path:
            Path to a file.
    
    """
    
    h = hashlib.sha1()
    with open(path) as fp:
        h.update(fp.read())
    return h.hexdigest()
    

def image_size(path):
    """Return the height and witdth of a given image
    
    **Parameters**
        
        :path:
            Path to a image file.
            
    **Return**
        (width, height)
    
    """
    p = ImageFile.Parser()
    with open(path, "rb") as fp:
        for data in fp:
            try:
                p.feed(data)
                if p.image:
                    break
            except:
                pass
    return p.image.size
    
    
def image_resize(path, ext, size_name, width, height, to_size_max):
    if max(width, height) < to_size_max:
        return os.path.basename(path)
    out = os.path.join(os.path.dirname(path), size_name + "." + ext)
    tow, toh = 0, 0
    if width > height:
        tow = to_size_max
        toh = (height * to_size_max) / width
    else:
        tow = (width * to_size_max) / height
        toh = to_size_max
    im = Image.open(path)
    im.thumbnail((tow, toh), Image.ANTIALIAS)
    im.save(out, core.EXT2FILTER[ext])
    return os.path.basename(out)


#===============================================================================
# MAIN
#===============================================================================

if __name__ == "__main__":
    print(__doc__)
